@@ -73,6 +73,8 @@ SOFTWARE.
 #include "swaprep.h"
 #include "dixevents.h"
 
+extern void XkbFreePrivates(DeviceIntPtr device);
+
 DeviceIntPtr
 AddInputDevice(DeviceProc deviceProc, Bool autoStart)
 {
@@ -203,7 +205,15 @@ CloseDevice(register DeviceIntPtr dev)
 
     if (dev->inited)
 	(void)(*dev->deviceProc)(dev, DEVICE_CLOSE);
+
+#ifdef XKB
+    while (dev->xkb_interest) {
+	XkbRemoveResourceClient((DevicePtr)dev,dev->xkb_interest->resource);
+    }
+#endif
+
     free(dev->name);
+
     if (dev->key)
     {
 #ifdef XKB
@@ -267,11 +277,13 @@ CloseDevice(register DeviceIntPtr dev)
 #endif
 	free(l);
     }
+
 #ifdef XKB
-    while (dev->xkb_interest) {
-	XkbRemoveResourceClient((DevicePtr)dev,dev->xkb_interest->resource);
-    }
+    XkbFreePrivates(dev);
 #endif
+
+    free(dev->devPrivates);
+
     free(dev->sync.event);
     free(dev);
 }
