@@ -195,7 +195,7 @@ int ddxProcessArgument(int argc, char *argv[], int i)
   {
     char *basec = strdup(argv[0]);
     nxagentProgName = strdup(basename(basec));
-    free(basec);
+    SAFE_free(basec);
 
     /*
      * Check if we are running as X2Go Agent
@@ -270,7 +270,7 @@ int ddxProcessArgument(int argc, char *argv[], int i)
     {
       nxagentParseOptionString(envOptions);
 
-      free(envOptions);
+      SAFE_free(envOptions);
     }
 
     for (j = 0; j < argc; j++)
@@ -378,8 +378,7 @@ int ddxProcessArgument(int argc, char *argv[], int i)
   {
     if (++i < argc)
     {
-      free(nxagentOptionsFilenameOrString);
-      nxagentOptionsFilenameOrString = NULL;
+      SAFE_free(nxagentOptionsFilenameOrString);
 
       if (-1 == asprintf(&nxagentOptionsFilenameOrString, "%s", argv[i]))
       {
@@ -716,8 +715,7 @@ int ddxProcessArgument(int argc, char *argv[], int i)
   {
     if (++i < argc)
     {
-      free(nxagentKeyboard);
-      nxagentKeyboard = NULL;
+      SAFE_free(nxagentKeyboard);
 
       nxagentKeyboard = strdup(argv[i]);
       if (nxagentKeyboard == NULL)
@@ -1041,6 +1039,14 @@ int ddxProcessArgument(int argc, char *argv[], int i)
     return 0;
   }
 
+  if (!strcmp(argv[i], "-autograb"))
+  {
+    nxagentChangeOption(AutoGrab, True);
+
+    return 1;
+  }
+
+
   /*
    * Disable Xinerama (i.e. fake it in Screen.c) if somehow Xinerama support
    * has been disabled on the cmdline.
@@ -1541,6 +1547,19 @@ static void nxagentParseSingleOption(char *name, char *value)
 
     return;
   }
+  else if (!strcmp(name, "autograb"))
+  {
+    if (!strcmp(value, "0"))
+    {
+      nxagentChangeOption(AutoGrab, False);
+    }
+    else
+    {
+      nxagentChangeOption(AutoGrab, True);
+    }
+
+    return;
+  }
   else
   {
     #ifdef DEBUG
@@ -1574,7 +1593,7 @@ static void nxagentParseSingleOption(char *name, char *value)
 
   ddxProcessArgument(argc, argv, 0);
 
-  free(argv[0]);
+  SAFE_free(argv[0]);
 }
 
 static void nxagentParseOptionString(char *string)
@@ -1761,7 +1780,7 @@ void nxagentProcessOptionsFile(char * filename)
 
 nxagentProcessOptionsFileExit:
 
-  free(data);
+  SAFE_free(data);
 
   if (file)
   {
@@ -2197,6 +2216,7 @@ void ddxUseMsg(void)
   ErrorF("-noignore              don't ignore pointer and keyboard configuration changes mandated by clients\n");
   ErrorF("-nokbreset             don't reset keyboard device if the session is resumed\n");
   ErrorF("-noxkblock             always allow applications to change layout through XKEYBOARD\n");
+  ErrorF("-autograb              enable autograb\n");
   ErrorF("-tile WxH              size of image tiles (minimum allowed: 32x32)\n");
   ErrorF("-keystrokefile file    file with keyboard shortcut definitions\n");
   ErrorF("-verbose               print more warning and error messages\n");
