@@ -99,6 +99,9 @@ char * nxagentSpecialKeystrokeNames[] = {
        "viewport_scroll_down",
 
        "reread_keystrokes",
+
+       "autograb",
+
        NULL,
 };
 
@@ -138,6 +141,7 @@ struct nxagentSpecialKeystrokeMap default_map[] = {
   {KEYSTROKE_VIEWPORT_SCROLL_DOWN, ControlMask, True, XK_Down},
   {KEYSTROKE_VIEWPORT_SCROLL_DOWN, ControlMask, True, XK_KP_Down},
   {KEYSTROKE_REREAD_KEYSTROKES, ControlMask, True, XK_k},
+  {KEYSTROKE_AUTOGRAB, ControlMask, True, XK_g},
   {KEYSTROKE_END_MARKER, 0, False, NoSymbol},
 };
 struct nxagentSpecialKeystrokeMap *map = default_map;
@@ -294,7 +298,7 @@ void nxagentInitKeystrokes(Bool force)
   if (force) {
     if (map != default_map)
     {
-      free(map);
+      SAFE_free(map);
       map = default_map;
     }
     fprintf(stderr, "Info: re-reading keystrokes configuration\n");
@@ -414,7 +418,7 @@ void nxagentInitKeystrokes(Bool force)
     #endif
     filename = NULL;
   }
-  free(homepath);
+  SAFE_free(homepath);
 
   if (map == default_map)
   {
@@ -467,7 +471,7 @@ static enum nxagentSpecialKeystroke find_keystroke(XKeyEvent *X)
   #endif
   for (struct nxagentSpecialKeystrokeMap *cur = map; cur->stroke != KEYSTROKE_END_MARKER; cur++) {
     #ifdef DEBUG
-    fprintf(stderr, "%s: checking keysym '%c' (%d)\n", __func__, cur->keysym, cur->keysym);
+    fprintf(stderr,"%s: keysym %d stroke %d, type %d\n", __func__, cur->keysym, cur->stroke, X->type);
     #endif
     if (cur->keysym == keysym && modifier_matches(cur->modifierMask, cur->modifierAltMeta, X->state)) {
       #ifdef DEBUG
@@ -480,6 +484,9 @@ static enum nxagentSpecialKeystroke find_keystroke(XKeyEvent *X)
   return ret;
 }
 
+/*
+ * returns True if a special keystroke has been pressed. *result will contain the action.
+ */
 Bool nxagentCheckSpecialKeystroke(XKeyEvent *X, enum HandleEventResult *result)
 {
   enum nxagentSpecialKeystroke stroke = find_keystroke(X);
@@ -624,10 +631,13 @@ Bool nxagentCheckSpecialKeystroke(XKeyEvent *X, enum HandleEventResult *result)
       if (X->type == KeyRelease)
 	nxagentInitKeystrokes(True);
       break;
+    case KEYSTROKE_AUTOGRAB:
+      *result = doAutoGrab;
+      break;
     case KEYSTROKE_NOTHING: /* do nothing. difference to KEYSTROKE_IGNORE is the return value */
     case KEYSTROKE_END_MARKER: /* just to make gcc STFU */
     case KEYSTROKE_MAX:
       break;
   }
-  return (*result == doNothing);
+  return (*result != doNothing);
 }
