@@ -52,11 +52,9 @@ unsigned        ndx;
 
     xkbi= keyc->xkbInfo;
     key= xE->u.u.detail;
-#ifdef DEBUG
     if (xkbDebugFlags&0x8) {
-	ErrorF("XkbPKE: Key %d %s\n",key,(xE->u.u.type==KeyPress?"down":"up"));
+	DebugF("XkbPKE: Key %d %s\n",key,(xE->u.u.type==KeyPress?"down":"up"));
     }
-#endif
 
     if ( (xkbi->repeatKey==key) && (xE->u.u.type==KeyRelease) &&
 	 ((xkbi->desc->ctrls->enabled_ctrls&XkbRepeatKeysMask)==0) ) {
