@@ -26,8 +26,6 @@
 
 #ifdef HAVE_DIX_CONFIG_H
 #include <dix-config.h>
-#elif defined(HAVE_CONFIG_H)
-#include <config.h>
 #endif
 
 #include <stdio.h>
@@ -36,7 +34,6 @@
 
 #include <nx-X11/Xos.h>
 
-
 #include <nx-X11/X.h>
 #include <nx-X11/Xproto.h>
 #include "misc.h"
@@ -46,7 +43,6 @@
 #include <xkbsrv.h>
 #include "xkbgeom.h"
 
-
 /***====================================================================***/
 
 #define	BUFFER_SIZE	512
@@ -73,16 +69,17 @@ char *rtrn;
 char *
 XkbAtomText(Display *dpy,Atom atm,unsigned format)
 {
+const char	*atmstr;
 char	*rtrn,*tmp;
 
-    tmp= (char *)NameForAtom(atm);
-    if (tmp!=NULL) {
+    atmstr= NameForAtom(atm);
+    if (atmstr!=NULL) {
 	int	len;
-	len= strlen(tmp)+1;
+	len= strlen(atmstr)+1;
 	if (len>BUFFER_SIZE)
 	    len= BUFFER_SIZE-2;
 	rtrn= tbGetBuffer(len);
-	strncpy(rtrn,tmp,len);
+	strncpy(rtrn,atmstr,len);
 	rtrn[len]= '\0';
     }
     else {
@@ -107,7 +104,8 @@ XkbVModIndexText(Display *dpy,XkbDescPtr xkb,unsigned ndx,unsigned format)
 {
 register int len;
 register Atom *vmodNames;
-char *rtrn,*tmp;
+char *rtrn;
+const char *tmp;
 char  numBuf[20];
 
     if (xkb && xkb->names)
@@ -118,9 +116,11 @@ char  numBuf[20];
     if (ndx>=XkbNumVirtualMods)
 	 tmp= "illegal";
     else if (vmodNames&&(vmodNames[ndx]!=None))
-	 tmp= (char *)NameForAtom(vmodNames[ndx]);
-    if (tmp==NULL)
-	sprintf(tmp=numBuf,"%d",ndx);
+        tmp= NameForAtom(vmodNames[ndx]);
+    if (tmp==NULL) {
+	sprintf(numBuf,"%d",ndx);
+	tmp = numBuf;
+    }
 
     len= strlen(tmp)+1;
     if (format==XkbCFile)
@@ -1323,4 +1323,3 @@ register int i;
     buf[size]= '\0';
     return buf;
 }
-
